module.exports = [
  {
    id: 'P64:test:allfiles_pattern',
    name: 'Test rule: matches files with an "f" character in their path using a basic regex test',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path using a basic regex to test each file.',
    urls: ['https://www.polaris64.net/blog/cyber-security', 'https://www.google.com/'],
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: /f+/,
      content: null,
    },
  },

  {
    id: 'P64:test:allfiles_callback_simple',
    name: 'Test rule: matches files with an "f" character in their path using a callback test function which returns a Boolean',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path using a callback test function which returns a Boolean.',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: (f) => f.split('').filter(c => c === 'f').length > 0,
      content: null,
    },
  },

  {
    id: 'P64:test:allfiles_callback_promise',
    name: 'Test rule: matches files with an "f" character in their path using a callback test function which returns a Promise',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path using a callback test function which returns a Promise which resolves to a Boolean.',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: (f) => {
        return new Promise((resolve) => {
          setTimeout(() => {
            resolve(f.split('').filter(c => c === 'f').length > 0);
          }, (Math.random() * 100) + 50);
        });
      },
      content: null,
    },
  },

  {
    id: 'P64:test:allfiles_empty_content',
    name: 'Test rule: matches files with an "f" character in their path and contain the word "exploit" (regex).',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path and the word "exploit" in their content.',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: /f/i,
      content: /exploit/i,
    },
  },

  {
    id: 'P64:test:allfiles_empty_content_callback',
    name: 'Test rule: matches files with an "f" character in their path and contain the word "exploit" (simple callback).',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path and the word "exploit" in their content.',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: /f/i,
      content: (content) => !!content.match(/exploit/i),
    },
  },

  {
    id: 'P64:test:allfiles_empty_content_promise_callback',
    name: 'Test rule: matches files with an "f" character in their path and contain the word "exploit" (Promise callback).',
    description: 'This rule is intended for debug purposes only. Matches files with an "f" character in their path and the word "exploit" in their content.',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: /f/i,
      content: (content) => new Promise((resolve) => resolve(content.match(/exploit/i))),
    },
  },

  {
    id: 'P64:test:PHP_scripts_with_dirname',
    name: 'Matches any PHP script that contains the text "dirname"',
    description: 'This rule is intended for debug purposes only. Matches all PHP scripts containing the text "dirname".',
    urls: null,
    deprecated: false,
    tags: ['debug'],
    tests: {
      path: /\.php$/i,
      content: /dirname/i,
    },
  },

  {
    id: 'P64:test:deprecated:PHP_scripts',
    name: 'Deprecated rule: matches all PHP scripts',
    description: 'This rule is intended for debug purposes only. Deprecated rule which matches all PHP scripts.',
    urls: null,
    deprecated: true,
    tags: ['debug'],
    tests: {
      path: /\.php$/i,
      content: null,
    },
  },
];
